@@ -188,7 +188,8 @@ class Profile(Base):
             [
                 (item.key, Optional[str], dataclasses.field(default=None))
                 for item in Attribute.__subclasses__()
-            ]
+            ],
+            bases=(Base,)
         )(**{item.key: item.value for item in self.attribute})
 
 
